package cn.com.qmth.examcloud.service.core.service;

import java.io.File;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import cn.com.qmth.examcloud.service.core.entity.Student;
import cn.com.qmth.examcloud.service.core.repo.StudentRepo;

/**
 * 学生服务类
 * Created by songyue on 17/1/14.
 */
@Service
public class StudentService {
    @Autowired
    StudentRepo studentRepo;

    /**
     * 获取所有学生(分页)
     * @param studentCriteria
     * @param pageable
     * @return
     */
    public Page<Student> getAllStudent(Student studentCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching();
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return studentRepo.findAll(studentExample,pageable);
    }

    /**
     * 获取所有学生
     * @param studentCriteria
     * @return
     */
    public List<Student> getAllStudent(Student studentCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching();
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return studentRepo.findAll(studentExample);
    }

    /**
     * 根据身份证更新学生照片
     * @param identityNumber
     * @return
     */
	public Student updateStudentPhoto(String identityNumber) {
		Student student = studentRepo.findByIdentityNumber(identityNumber);
		student.setPhotoPath(student.getUser().getOrgId()+File.separator+"photo"+ File.separator+identityNumber);
		return studentRepo.save(student);
	}

}
